from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .....UtilityAndView.abaqusConstants import Boolean, OFF


@abaqus_class_doc
class VoidNucleation:
    r"""The VoidNucleation object defines the nucleation of voids in a porous material.

    .. note:: 
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].porousMetalPlasticity.voidNucleation
            import odbMaterial
            session.odbs[name].materials[name].porousMetalPlasticity.voidNucleation

        The table data for this object are:

        - :math:`\varepsilon_{N}`, the mean value of the nucleation-strain normal distribution.
        - :math:`s_{N}`, the standard deviation of the nucleation-strain normal distribution.
        - :math:`f_{N}`, the volume fraction of nucleating voids.
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - VOID NUCLEATION
    """

    @abaqus_method_doc
    def __init__(
        self, table: tuple, temperatureDependency: Boolean = OFF, dependencies: int = 0
    ):
        """This method creates a VoidNucleation object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].materials[name].porousMetalPlasticity.VoidNucleation
                    session.odbs[name].materials[name].porousMetalPlasticity.VoidNucleation
            
        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below. 
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF. 
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0. 

        Returns
        -------
        VoidNucleation
            A :py:class:`~abaqus.Material.Plastic.Metal.Porous.VoidNucleation.VoidNucleation` object. 

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the VoidNucleation object.

        Raises
        ------
        RangeError
        """
        ...



from typing import Optional

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .AxisData import AxisData
from .LineStyle import LineStyle
from .TextStyle import TextStyle
from ..UtilityAndView.abaqusConstants import INSIDE, MIN_MAX_EDGE, SymbolicConstant


@abaqus_class_doc
class Axis:
    """The Axis object is used to store the display attributes of axes. Axes objects are
    automatically created when adding XYCurve objects to a Chart object.

    .. note:: 
        This object can be accessed by::

            import visualization
            session.charts[name].axes1[i]
            session.charts[name].axes2[i]
            session.defaultChartOptions.defaultAxis1Options
            session.defaultChartOptions.defaultAxis2Options
            session.xyPlots[name].charts[name].axes1[i]
            session.xyPlots[name].charts[name].axes2[i]
    """

    #: An Int specifying the frequency of the labels with respect to the tick marks. The
    #: default value is 1.
    labelFrequency: int = 1

    #: A Float specifying the length of the ticks in mm. The default value is 2.0.
    tickLength: float = 2

    #: A SymbolicConstant specifying the placement of the axis on the grid. Possible values
    #: are:MIN_EDGE, specifying that the axis is placed at the minimum edge - for an abscissa
    #: at the bottom, for an ordinate to the left.MAX_EDGE, specifying that the axis is placed
    #: at the maximum edge - for an abscissa at the top, for an ordinate at the
    #: right.MIN_MAX_EDGE, specifying that the axis is placed at the minimum edge - for an
    #: abscissa at the bottom, for an ordinate to the left - and repeated without labels and
    #: title at the maximum edge.CENTER, specifying that the axis is placed at the center of
    #: the grid.The default value is MIN_MAX_EDGE.
    placement: SymbolicConstant = MIN_MAX_EDGE

    #: A SymbolicConstant specifying how tick marks are placed on the axis. Possible values
    #: are:NONE, specifying that no tick marks are displayed.INSIDE, specifying that the tick
    #: marcks are placed on the inside of the axis.OUTSIDE, specifying that the tick marcks are
    #: placed on the outside of the axis.ACROSS, specifying that the tick marcks are placed
    #: across the axis.The default value is INSIDE.
    tickPlacement: SymbolicConstant = INSIDE

    #: A SymbolicConstant specifying how labels are placed on the axis. Possible values
    #: are:NONE, specifying that no labels are displayed.INSIDE, specifying that the labels are
    #: placed on the inside of the axis.OUTSIDE, specifying that the labels are placed on the
    #: outside of the axis.The default value is INSIDE.
    labelPlacement: SymbolicConstant = INSIDE

    #: An :py:class:`~abaqus.XY.AxisData.AxisData` object specifying the numerical data of the axis.
    axisData: AxisData = AxisData()

    #: A :py:class:`~abaqus.XY.LineStyle.LineStyle` object specifying the line properties used to display the axis.
    lineStyle: LineStyle = LineStyle()

    #: A :py:class:`~abaqus.XY.TextStyle.TextStyle` object specifying the text properties to be used when displaying axis
    #: labels.
    labelStyle: TextStyle = TextStyle()

    #: A :py:class:`~abaqus.XY.TextStyle.TextStyle` object specifying the text properties to be used when displaying the axis
    #: title.
    titleStyle: TextStyle = TextStyle()

    #: A :py:class:`~abaqus.XY.LineStyle.LineStyle` object specifying the line properties to be used when displaying axis ticks.
    tickStyle: LineStyle = LineStyle()

    @abaqus_method_doc
    def setValues(
        self,
        axis: "Axis",
        labelFrequency: int = 1,
        labelPlacement: SymbolicConstant = INSIDE,
        labelStyle: Optional[TextStyle] = None, 
        lineStyle: Optional[LineStyle] = None, 
        placement: SymbolicConstant = MIN_MAX_EDGE,
        tickLength: float = 2,
        tickPlacement: SymbolicConstant = INSIDE,
        tickStyle: Optional[LineStyle] = None, 
        titleStyle: Optional[TextStyle] = None, 
    ):
        """This method modifies the Axis object.

        Parameters
        ----------
        axis
            An :py:class:`~abaqus.XY.Axis.Axis` object from which attributes are to be copied.
        labelFrequency
            An Int specifying the frequency of the labels with respect to the tick marks. The
            default value is 1.
        labelPlacement
            A SymbolicConstant specifying how labels are placed on the axis. Possible values
            are:NONE, specifying that no labels are displayed.INSIDE, specifying that the labels are
            placed on the inside of the axis.OUTSIDE, specifying that the labels are placed on the
            outside of the axis.The default value is INSIDE.
        labelStyle
            A :py:class:`~abaqus.XY.TextStyle.TextStyle` object specifying the text properties to be used when displaying axis
            labels.
        lineStyle
            A :py:class:`~abaqus.XY.LineStyle.LineStyle` object specifying the line properties used to display the axis.
        placement
            A SymbolicConstant specifying the placement of the axis on the grid. Possible values
            are:MIN_EDGE, specifying that the axis is placed at the minimum edge - for an abscissa
            at the bottom, for an ordinate to the left.MAX_EDGE, specifying that the axis is placed
            at the maximum edge - for an abscissa at the top, for an ordinate at the
            right.MIN_MAX_EDGE, specifying that the axis is placed at the minimum edge - for an
            abscissa at the bottom, for an ordinate to the left - and repeated without labels and
            title at the maximum edge.CENTER, specifying that the axis is placed at the center of
            the grid.The default value is MIN_MAX_EDGE.
        tickLength
            A Float specifying the length of the ticks in mm. The default value is 2.0.
        tickPlacement
            A SymbolicConstant specifying how tick marks are placed on the axis. Possible values
            are:NONE, specifying that no tick marks are displayed.INSIDE, specifying that the tick
            marcks are placed on the inside of the axis.OUTSIDE, specifying that the tick marcks are
            placed on the outside of the axis.ACROSS, specifying that the tick marcks are placed
            across the axis.The default value is INSIDE.
        tickStyle
            A :py:class:`~abaqus.XY.LineStyle.LineStyle` object specifying the line properties to be used when displaying axis ticks.
        titleStyle
            A :py:class:`~abaqus.XY.TextStyle.TextStyle` object specifying the text properties to be used when displaying the axis
            title.
        """
        ...



from typing import Optional

from abqpy.decorators import abaqus_class_doc
from ..UtilityAndView.abaqusConstants import SymbolicConstant


@abaqus_class_doc
class Message:
    """The Message object contains information about a given phase of the simulation. Job
    messages are not returned if a script is run without the Abaqus/CAE GUI (using the noGUI
    option).

    .. note:: 
        This object can be accessed by::

            import job
            mdb.coexecutions[name].jobs[name].messages[i]
            mdb.jobs[name].messages[i]
    """

    #: A SymbolicConstant specifying the type of message. Possible values are:
    #: 
    #: - ABORTED
    #: - ANY_JOB
    #: - ANY_MESSAGE_TYPE
    #: - COMPLETED
    #: - END_STEP
    #: - ERROR
    #: - HEADING
    #: - HEALER_JOB
    #: - HEALER_TYPE
    #: - INTERRUPTED
    #: - ITERATION
    #: - JOB_ABORTED
    #: - JOB_COMPLETED
    #: - JOB_INTERRUPTED
    #: - JOB_SUBMITTED
    #: - MONITOR_DATA
    #: - ODB_FILE
    #: - ODB_FRAME
    #: - STARTED
    #: - STATE_FRAME
    #: - STATUS
    #: - STEP
    #: - WARNING
    type: Optional[SymbolicConstant] = None

    #: A Dictionary object specifying the data returned by the analysis product. The value
    #: depends on the message returned. For a list of the possible entries, see the members of
    #: DataObject.
    data: Optional[dict] = None



from typing import Optional

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .ConnectorOrientation import ConnectorOrientation
from ..Canvas.Displayable import Displayable
from ..Datum.DatumCsys import DatumCsys
from ..EditMesh.MeshEditAssembly import MeshEditAssembly
from ..Mesh.MeshAssembly import MeshAssembly
from ..Property.PropertyAssembly import PropertyAssembly
from ..Region.RegionAssembly import RegionAssembly
from ..Region.Set import Set
from ..UtilityAndView.abaqusConstants import AXIS_1, Boolean, ON, SymbolicConstant


@abaqus_class_doc
class Assembly(MeshEditAssembly, MeshAssembly, PropertyAssembly, RegionAssembly, Displayable):
    """An :py:class:`~abaqus.Assembly.Assembly.Assembly` object is a container for instances of parts. The Assembly object has no
    constructor command. Abaqus creates the **rootAssembly** member when a Model object is
    created.

    .. note:: 
        This object can be accessed by::

            import assembly
            mdb.models[name].rootAssembly
    """

    @abaqus_method_doc
    def ConnectorOrientation(
        self,
        region: Set,
        localCsys1: Optional[DatumCsys] = None,
        axis1: SymbolicConstant = AXIS_1,
        angle1: float = 0,
        orient2sameAs1: Boolean = ON,
        localCsys2: Optional[DatumCsys] = None,
        axis2: SymbolicConstant = AXIS_1,
        angle2: float = 0,
    ) -> ConnectorOrientation:
        """This method creates a ConnectorOrientation object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].rootAssembly.ConnectorOrientation
                session.odbs[name].rootAssembly.ConnectorOrientation

        Parameters
        ----------
        region
            A :py:class:`~abaqus.Region.Set.Set` object specifying the region to which the orientation is assigned.
        localCsys1
            A :py:class:`~abaqus.Datum.DatumCsys.DatumCsys` object specifying the local coordinate system of the first connector point.
            This value may be None, indicating the global coordinate system.
        axis1
            A SymbolicConstant specifying the axis of a datum coordinate system about which an
            additional rotation is applied. Possible values are AXIS_1, AXIS_2, and AXIS_3. The
            default value is AXIS_1.
        angle1
            A Float specifying the angle of the additional rotation. The default value is 0.0.
        orient2sameAs1
            A Boolean specifying whether or not the second connector point is to use the same local
            coordinate system, axis, and angle as the first point. The default value is ON.
        localCsys2
            A :py:class:`~abaqus.Datum.DatumCsys.DatumCsys` object specifying the local coordinate system of the second connector point.
            This value may be None, indicating the global coordinate system.
        axis2
            A SymbolicConstant specifying the axis of a datum coordinate system about which an
            additional rotation is applied. Possible values are AXIS_1, AXIS_2, and AXIS_3. The
            default value is AXIS_1.
        angle2
            A Float specifying the angle of the additional rotation. The default value is 0.0.

        Returns
        -------
        ConnectorOrientation
            A :py:class:`~abaqus.Assembly.ConnectorOrientation.ConnectorOrientation` object.
        """
        connectorOrientation = ConnectorOrientation(
            region, localCsys1, axis1, angle1, orient2sameAs1, localCsys2, axis2, angle2
        )
        self.connectorOrientations.append(connectorOrientation)
        return connectorOrientation



from typing import Union, Optional

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .BoundaryCondition import BoundaryCondition
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import (Boolean, NOT_APPLICABLE, OFF, SET, SymbolicConstant,
                                              UNIFORM, UNSET)


@abaqus_class_doc
class ConnDisplacementBC(BoundaryCondition):
    """The ConnDisplacementBC object stores the data for a connector displacement/rotation
    boundary condition.
    The ConnDisplacementBC object is derived from the BoundaryCondition object.

    .. note:: 
        This object can be accessed by::

            import load
            mdb.models[name].boundaryConditions[name]
    """

    #: A String specifying the boundary condition repository key.
    name: str = ""

    #: A Boolean specifying whether the boundary condition should remain fixed at the current
    #: values at the start of the step. The default value is OFF.
    fixed: Boolean = OFF

    #: A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
    #: analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
    #: PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
    buckleCase: SymbolicConstant = NOT_APPLICABLE

    #: A SymbolicConstant specifying how the boundary condition is distributed spatially.
    #: Possible values are UNIFORM and USER_DEFINED. The default value is UNIFORM.
    distributionType: SymbolicConstant = UNIFORM

    #: A String specifying the name of the assembled fastener to which the boundary condition
    #: will be applied. This argument is not valid when **region** is specified. When this
    #: argument is specified, **fastenerSetName** must also be specified. The default value is an
    #: empty string.
    fastenerName: str = ""

    #: A String specifying the assembled fastener template model set to which the boundary
    #: condition will be applied. This argument is not valid when **region** is specified. When
    #: this argument is specified, **fastenerName** must also be specified. The default value is
    #: an empty string.
    fastenerSetName: str = ""

    #: A SymbolicConstant specifying the category of the boundary condition. Possible values
    #: are MECHANICAL and THERMAL.
    category: Optional[SymbolicConstant] = None

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
    region: Region = Region()

    #: None or a DatumCsys object specifying the local coordinate system of the boundary
    #: condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
    #: in the global coordinate system. The default value is None.
    localCsys: Optional[str] = None

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        region: str = "",
        fastenerName: str = "",
        fastenerSetName: str = "",
        u1: Union[SymbolicConstant, float] = UNSET,
        u2: Union[SymbolicConstant, float] = UNSET,
        u3: Union[SymbolicConstant, float] = UNSET,
        ur1: Union[SymbolicConstant, float] = UNSET,
        ur2: Union[SymbolicConstant, float] = UNSET,
        ur3: Union[SymbolicConstant, float] = UNSET,
        fixed: Boolean = OFF,
        amplitude: str = UNSET,
        distributionType: SymbolicConstant = UNIFORM,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
    ):
        """This method creates a ConnDisplacementBC object on a wire region. Alternatively, the
        boundary condition may also be applied to a wire set referenced from an assembled
        fastener template model.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].ConnDisplacementBC

        Parameters
        ----------
        name
            A String specifying the boundary condition repository key.
        createStepName
            A String specifying the name of the step in which the boundary condition is created.
        region
            The wire region to which the boundary condition is applied. This argument is not valid
            when **fastenerName** and **fastenerSetName** are specified.
        fastenerName
            A String specifying the name of the assembled fastener to which the boundary condition
            will be applied. This argument is not valid when **region** is specified. When this
            argument is specified, **fastenerSetName** must also be specified. The default value is an
            empty string.
        fastenerSetName
            A String specifying the assembled fastener template model set to which the boundary
            condition will be applied. This argument is not valid when **region** is specified. When
            this argument is specified, **fastenerName** must also be specified. The default value is
            an empty string.
        u1
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            connector's local 1-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.Note:Although **u1**, **u2**, **u3**, **ur1**, **ur2**, and **ur3**
            are optional arguments, at least one of them must be specified.
        u2
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            connector's local 2-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        u3
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            connector's local 3-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        ur1
            A Float, a Complex, or a SymbolicConstant specifying the rotational component in the
            connector's local 4-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        ur2
            A Float, a Complex, or a SymbolicConstant specifying the rotational component in the
            connector's local 5-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        ur3
            A Float, a Complex, or a SymbolicConstant specifying the rotational component in the
            connector's local 6-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        fixed
            A Boolean specifying whether the boundary condition should remain fixed at the current
            values at the start of the step. The default value is OFF.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the boundary condition has no amplitude reference. The default
            value is UNSET. You should provide the **amplitude** argument only if it is valid for the
            specified step.
        distributionType
            A SymbolicConstant specifying how the boundary condition is distributed spatially.
            Possible values are UNIFORM and USER_DEFINED. The default value is UNIFORM.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.

        Returns
        -------
        ConnDisplacementBC
            A :py:class:`~abaqus.BoundaryCondition.ConnDisplacementBC.ConnDisplacementBC` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        region: str = "",
        fastenerName: str = "",
        fastenerSetName: str = "",
        u1: Union[SymbolicConstant, float] = UNSET,
        u2: Union[SymbolicConstant, float] = UNSET,
        u3: Union[SymbolicConstant, float] = UNSET,
        ur1: Union[SymbolicConstant, float] = UNSET,
        ur2: Union[SymbolicConstant, float] = UNSET,
        ur3: Union[SymbolicConstant, float] = UNSET,
        fixed: Boolean = OFF,
        amplitude: str = UNSET,
        distributionType: SymbolicConstant = UNIFORM,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
    ):
        """This method modifies the data for an existing ConnDisplacementBC object in the step
        where it is created.

        Parameters
        ----------
        region
            The wire region to which the boundary condition is applied. This argument is not valid
            when **fastenerName** and **fastenerSetName** are specified.
        fastenerName
            A String specifying the name of the assembled fastener to which the boundary condition
            will be applied. This argument is not valid when **region** is specified. When this
            argument is specified, **fastenerSetName** must also be specified. The default value is an
            empty string.
        fastenerSetName
            A String specifying the assembled fastener template model set to which the boundary
            condition will be applied. This argument is not valid when **region** is specified. When
            this argument is specified, **fastenerName** must also be specified. The default value is
            an empty string.
        u1
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            connector's local 1-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.Note:Although **u1**, **u2**, **u3**, **ur1**, **ur2**, and **ur3**
            are optional arguments, at least one of them must be specified.
        u2
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            connector's local 2-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        u3
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            connector's local 3-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        ur1
            A Float, a Complex, or a SymbolicConstant specifying the rotational component in the
            connector's local 4-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        ur2
            A Float, a Complex, or a SymbolicConstant specifying the rotational component in the
            connector's local 5-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        ur3
            A Float, a Complex, or a SymbolicConstant specifying the rotational component in the
            connector's local 6-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        fixed
            A Boolean specifying whether the boundary condition should remain fixed at the current
            values at the start of the step. The default value is OFF.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the boundary condition has no amplitude reference. The default
            value is UNSET. You should provide the **amplitude** argument only if it is valid for the
            specified step.
        distributionType
            A SymbolicConstant specifying how the boundary condition is distributed spatially.
            Possible values are UNIFORM and USER_DEFINED. The default value is UNIFORM.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        """
        ...

    @abaqus_method_doc
    def setValuesInStep(
        self,
        stepName: str,
        u1: Union[SymbolicConstant, float] = SET,
        u2: Union[SymbolicConstant, float] = SET,
        u3: Union[SymbolicConstant, float] = SET,
        ur1: Union[SymbolicConstant, float] = SET,
        ur2: Union[SymbolicConstant, float] = SET,
        ur3: Union[SymbolicConstant, float] = SET,
        amplitude: str = "",
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
    ):
        """This method modifies the propagating data for an existing ConnDisplacementBC object in
        the specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the boundary condition is modified.
        u1
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            connector's local 1-direction. Possible values for the SymbolicConstant are SET,
            UNCHANGED, and FREED.
        u2
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            connector's local 2-direction. Possible values for the SymbolicConstant are SET,
            UNCHANGED, and FREED.
        u3
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            connector's local 3-direction. Possible values for the SymbolicConstant are SET,
            UNCHANGED, and FREED.
        ur1
            A Float, a Complex, or a SymbolicConstant specifying the rotational component in the
            connector's local 4-direction. Possible values for the SymbolicConstant are SET,
            UNCHANGED, and FREED.
        ur2
            A Float, a Complex, or a SymbolicConstant specifying the rotational component in the
            connector's local 5-direction. Possible values for the SymbolicConstant are SET,
            UNCHANGED, and FREED.
        ur3
            A Float, a Complex, or a SymbolicConstant specifying the rotational component in the
            connector's local 6-direction. Possible values for the SymbolicConstant are SET,
            UNCHANGED, and FREED.
        amplitude
            A String or a SymbolicConstant specifying the name of the amplitude reference. Possible
            values for the SymbolicConstant are UNCHANGED and FREED. UNCHANGED should be used if the
            amplitude is propagated from the previous analysis step. FREED should be used if the
            boundary condition is changed to have no amplitude reference. You should provide the
            **amplitude** argument only if it is valid for the specified step.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .FailStrain import FailStrain
from .FailStress import FailStress
from ....UtilityAndView.abaqusConstants import Boolean, ISOTROPIC, LONG_TERM, OFF, SymbolicConstant


@abaqus_class_doc
class Elastic:
    r"""The Elastic object specifies elastic material properties.

    .. note:: 
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].elastic
            import odbMaterial
            session.odbs[name].materials[name].elastic

        The table data for this object are:

        - If **type** = ISOTROPIC, the table data specify the following:
        
            - The Young's modulus, :math:`E`.
            - The Poisson's ratio, :math:`\nu`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
            
        - If **type** = SHEAR, the table data specify the following:
        
            - The shear modulus, :math:`G`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
            
        - If **type** = ENGINEERING_CONSTANTS, the table data specify the following:
        
            - :math:`E_{1}`.
            - :math:`E_{2}`.
            - :math:`E_{3}`.
            - :math:`\nu_{12}`.
            - :math:`\nu_{13}`.
            - :math:`\nu_{23}`.
            - :math:`G_{12}`.
            - :math:`G_{13}`.
            - :math:`G_{23}`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
            
        - If **type** = LAMINA, the table data specify the following:
        
            - :math:`E_{1}`.
            - :math:`E_{2}`.
            - :math:`\nu_{12}`.
            - :math:`G_{12}`.
            - :math:`G_{13}`. This shear modulus is needed to define transverse shear behavior in shells.
            - :math:`G_{23}`. This shear modulus is needed to define transverse shear behavior in shells.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
            
        - If **type** = ORTHOTROPIC, the table data specify the following:
        
            - :math:`D_{1111}`
            - :math:`D_{1122}`
            - :math:`D_{2222}`
            - :math:`D_{1133}`
            - :math:`D_{2233}`
            - :math:`D_{3333}`
            - :math:`D_{1212}`
            - :math:`D_{1313}`
            - :math:`D_{2323}`
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
            
        - If **type** = ANISOTROPIC, the table data specify the following:
        
            - :math:`D_{1111}`.
            - :math:`D_{1122}`.
            - :math:`D_{2222}`.
            - :math:`D_{1133}`.
            - :math:`D_{2233}`.
            - :math:`D_{3333}`.
            - :math:`D_{1112}`.
            - :math:`D_{2212}`.
            - :math:`D_{3312}`.
            - :math:`D_{1212}`.
            - :math:`D_{1113}`.
            - :math:`D_{2213}`.
            - :math:`D_{3313}`.
            - :math:`D_{1213}`.
            - :math:`D_{1313}`.
            - :math:`D_{1123}`.
            - :math:`D_{2223}`.
            - :math:`D_{3323}`.
            - :math:`D_{1223}`.
            - :math:`D_{1323}`.
            - :math:`D_{2323}`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
            
        - If **type** = TRACTION, the table data specify the following:
        
            - :math:`E` for warping elements; :math:`E_{nn}` for cohesive elements.
            - :math:`G_1` for warping elements; :math:`E_{ss}` for cohesive elements.
            - :math:`G_2` for warping elements; :math:`E_{tt}` for cohesive elements.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
            
        - If **type** = BILAMINA, the table data specify the following:
        
            - :math:`E_{n n}`.
            - :math:`E_{s s}`.
            - :math:`E_{t t}`.
            - :math:`E_{n s}`.
            - :math:`E_{n t}`.
            - :math:`E_{s t}`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
            
        - If **type** = SHORT_FIBER, there is no table data.

        The corresponding analysis keywords are:

        - ELASTIC
    """

    #: A :py:class:`~abaqus.Material.Elastic.Linear.FailStress.FailStress` object.
    failStress: FailStress = FailStress(((),))

    #: A :py:class:`~abaqus.Material.Elastic.Linear.FailStrain.FailStrain` object.
    failStrain: FailStrain = FailStrain(((),))

    @abaqus_method_doc
    def __init__(
        self,
        table: tuple,
        type: SymbolicConstant = ISOTROPIC,
        noCompression: Boolean = OFF,
        noTension: Boolean = OFF,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        moduli: SymbolicConstant = LONG_TERM,
    ):
        """This method creates an Elastic object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].materials[name].Elastic
                session.odbs[name].materials[name].Elastic

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        type
            A SymbolicConstant specifying the type of elasticity data provided. Possible values are:

            - ISOTROPIC
            - ORTHOTROPIC
            - ANISOTROPIC
            - ENGINEERING_CONSTANTS
            - LAMINA
            - TRACTION
            - COUPLED_TRACTION
            - SHORT_FIBER
            - SHEAR
            - BILAMINA
            
            The default value is ISOTROPIC.
        noCompression
            A Boolean specifying whether compressive stress is allowed. The default value is OFF.
        noTension
            A Boolean specifying whether tensile stress is allowed. The default value is OFF.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        moduli
            A SymbolicConstant specifying the time-dependence of the elastic material constants.
            Possible values are INSTANTANEOUS and LONG_TERM. The default value is LONG_TERM.

        Returns
        -------
        Elastic
            An :py:class:`~abaqus.Material.Elastic.Linear.Elastic.Elastic` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the Elastic object.

        Raises
        ------
        RangeError
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .GeometricRestriction import GeometricRestriction
from ..Region.Region import Region


@abaqus_class_doc
class BeadGrowth(GeometricRestriction):
    """The BeadGrowth object defines a growth geometric restriction.
    The BeadGrowth object is derived from the GeometricRestriction object.

    .. note:: 
        This object can be accessed by::

            import optimization
            mdb.models[name].optimizationTasks[name].geometricRestrictions[name]
    """

    #: A String specifying the geometric restriction repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the geometric restriction is applied.
    region: Region

    #: A Float specifying the maximum optimization displacement in the growth direction. Either
    #: **beadGrowth** or **shrink** or both must be specified. The default value is 0.0.
    beadGrowth: float = 0

    #: A Float specifying the maximum optimization displacement in the shrink direction. Either
    #: **beadGrowth** or **shrink** or both must be specified The default value is 0.0.
    shrink: float = 0

    @abaqus_method_doc
    def __init__(
        self, name: str, region: Region, beadGrowth: float = 0, shrink: float = 0
    ):
        """This method creates a BeadGrowth object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].optimizationTasks[name].BeadGrowth

        Parameters
        ----------
        name
            A String specifying the geometric restriction repository key.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the geometric restriction is applied.
        beadGrowth
            A Float specifying the maximum optimization displacement in the growth direction. Either
            **beadGrowth** or **shrink** or both must be specified. The default value is 0.0.
        shrink
            A Float specifying the maximum optimization displacement in the shrink direction. Either
            **beadGrowth** or **shrink** or both must be specified The default value is 0.0.

        Returns
        -------
        BeadGrowth
            A :py:class:`~abaqus.Optimization.BeadGrowth.BeadGrowth` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, beadGrowth: float = 0, shrink: float = 0):
        """This method modifies the BeadGrowth object.

        Parameters
        ----------
        beadGrowth
            A Float specifying the maximum optimization displacement in the growth direction. Either
            **beadGrowth** or **shrink** or both must be specified. The default value is 0.0.
        shrink
            A Float specifying the maximum optimization displacement in the shrink direction. Either
            **beadGrowth** or **shrink** or both must be specified The default value is 0.0.
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .Section import Section


@abaqus_class_doc
class TrussSection(Section):
    """The TrussSection object defines the properties of a truss section.
    The TrussSection object is derived from the Section object.

    .. note:: 
        This object can be accessed by::

            import section
            mdb.models[name].sections[name]
            import odbSection
            session.odbs[name].sections[name]

        The corresponding analysis keywords are:

        - SOLID SECTION
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the material.
    material: str

    #: A Float specifying the cross-sectional area for the section. Possible values are **area**
    #: >> 0. The default value is 1.0.
    area: float = 1

    @abaqus_method_doc
    def __init__(self, name: str, material: str, area: float = 1):
        """This method creates a TrussSection object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].TrussSection
                session.odbs[name].TrussSection

        Parameters
        ----------
        name
            A String specifying the repository key.
        material
            A String specifying the name of the material.
        area
            A Float specifying the cross-sectional area for the section. Possible values are **area**
            >> 0. The default value is 1.0.

        Returns
        -------
        TrussSection
            A :py:class:`~abaqus.Section.TrussSection.TrussSection` object.

        Raises
        ------
        RangeError and InvalidNameError
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, area: float = 1):
        """This method modifies the TrussSection object.

        Parameters
        ----------
        area
            A Float specifying the cross-sectional area for the section. Possible values are **area**
            >> 0. The default value is 1.0.

        Raises
        ------
        RangeError
        """
        ...



import os
import re
import sys
from types import NoneType

from abaqus.Session.Session import Session

from abaqus.UtilityAndView import SymbolicConstant, BackwardCompatibility

from abaqus import Mdb, backwardCompatibility, getInput, mdb
from abaqus.UtilityAndView.AbaqusBoolean import AbaqusBoolean
from abaqus.UtilityAndView.Repository import Repository
from abaqus.UtilityAndView.abaqusConstants import (AbaqusBooleanType, Boolean, BooleanType, CFD, EMAG, FALSE, NOT_SET,
                                                   OFF, ON, SCATTERED, STANDARD_EXPLICIT, STEP_END,
                                                   SymbolicConstantType, TOTAL, TRUE)


def upgradeMdb(*args, **kwargs):
    pass


MdbType = type(Mdb)
BackwardCompatibilityType = type(BackwardCompatibility)
SessionType = type(Session)
RepositoryType = type(Repository)


# Inspected from Abaqus/CAE 2021 Command Line Interface
__all__ = [
    'AbaqusBoolean',
    'AbaqusBooleanType',
    # 'AbaqusException',
    # 'AbaqusShutdown',
    'BackwardCompatibilityType',
    'Boolean',
    'BooleanType',
    'CFD',
    'EMAG',
    'FALSE',
    'Mdb',
    'MdbType',
    'NOT_SET',
    'NoneType',
    'OFF',
    'ON',
    'RepositoryType',
    'SCATTERED',
    'STANDARD_EXPLICIT',
    'STEP_END',
    'SessionType',
    'SymbolicConstant',
    'SymbolicConstantType',
    'TOTAL',
    'TRUE',
    # '__builtins__',
    # '__doc__',
    # '__name__',
    # '__package__',
    # '_fireQuery',
    # '_getCurrentExecFileCmd',
    # '_getDebug',
    # '_getMdbSchema',
    # '_getMdbUpToDateStatus',
    # '_getShowDisplaysState',
    # '_getShowLandmarksState',
    # '_getShowVerbosesState',
    # '_getShowWarningsState',
    # '_getWarningReply',
    # '_journalMethodCallInternal',
    # '_listDebug',
    # '_pprint',
    # '_printToCli',
    # '_replayCapture',
    # '_setCallVerifyMdb',
    # '_setDebug',
    # '_setImportModuleHook',
    # '_setMessagesState',
    # '_shutdowm',
    # '_upgradeTableMdb',
    # 'addCmdToCommandHistory',
    # 'applicationName',
    'backwardCompatibility',
    # 'compress',
    # 'copyrightYear',
    'getInput',
    # 'getInputs',
    # 'getMdbVersionNumbers',
    # 'getReplayFileName',
    # 'isMdbChanged',
    # 'isMdbStudentEdition',
    # 'isStudentEdition',
    # 'journalMethodDecrement',
    # 'journalMethodIncrement',
    # 'landmark',
    # 'majorVersion',
    'mdb',
    # 'mdbVersion',
    # 'milestone',
    # 'minorVersion',
    # 'odbVersion',
    # 'openMdb',
    'os',
    're',
    # 'showStopButtonInGui',
    'sys',
    # 'uncompress',
    # 'updateVersion',
    'upgradeMdb',
    # 'version'
]



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from ..UtilityAndView.abaqusConstants import SymbolicConstant


@abaqus_class_doc
class SlidingTransitionAssignment:
    """The SlidingTransitionAssignment object stores the sliding transition assignment
    definition for surfaces in ContactStd objects. The SlidingTransitionAssignment object
    has no constructor or members.

    .. note:: 
        This object can be accessed by::

            import interaction
            mdb.models[name].interactions[name].slidingTransitionAssignments

        The corresponding analysis keywords are:

        - CONTACT FORMULATION
    """

    @abaqus_method_doc
    def changeValuesInStep(self, stepName: str, index: int, value: SymbolicConstant):
        """This method allows you to modify sliding transition assignments already defined on
        surface pairs in a given step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the sliding transition assignments are
            to be modified.
        index
            An Int specifying the position of the sliding transition assignment whose value is to be
            modified.
        value
            A SymbolicConstant specifying the value of the smoothness of the surface-to-surface
            formulation on sliding to be assigned to the surface whose index is referenced. Possible
            values are ELEMENT_ORDER_SMOOTHING, LINEAR_SMOOTHING, and QUADRATIC_SMOOTHING.
        """
        ...

    @abaqus_method_doc
    def appendInStep(self, stepName: str, assignments: SymbolicConstant):
        """This method allows you to add sliding transition assignments to new surface pairs in a
        given step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the sliding transition assignments are
            to be defined.
        assignments
            A sequence of tuples specifying the sliding transition assignments. Each tuple contains
            two entries:A region object or the SymbolicConstant GLOBAL specifying the surface to
            which the sliding transition attribute is assigned.A SymbolicConstant specifying the
            overriding the smoothness value to be used for the first surface. Possible values of the
            SymbolicConstant are ELEMENT_ORDER_SMOOTHING, LINEAR_SMOOTHING, and QUADRATIC_SMOOTHING.
        """
        ...

    @abaqus_method_doc
    def delete(self, indices: tuple):
        """The delete method allows you to delete existing sliding transition assignments.

        Parameters
        ----------
        indices
            A sequence of Ints specifying the index of each sliding transition assignment to delete.
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .....UtilityAndView.abaqusConstants import Boolean, OFF


@abaqus_class_doc
class CycledPlastic:
    """The CycledPlastic object specifies cycled yield stress data for the ORNL constitutive
    model.

    .. note:: 
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].Plastic.cycledPlastic
            import odbMaterial
            session.odbs[name].materials[name].Plastic.cycledPlastic

        The table data for this object are:

        - Yield stress.
        - Plastic strain.
        - Temperature, if the data depend on temperature.

        The corresponding analysis keywords are:

        - CYCLED PLASTIC
    """

    @abaqus_method_doc
    def __init__(self, table: tuple, temperatureDependency: Boolean = OFF):
        """This method creates a CycledPlastic object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].materials[name].Plastic.CycledPlastic
                session.odbs[name].materials[name].Plastic.CycledPlastic

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.

        Returns
        -------
        CycledPlastic
            A :py:class:`~abaqus.Material.Plastic.Metal.Cyclic.CycledPlastic.CycledPlastic` object.
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the CycledPlastic object."""
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class Depvar:
    """The Depvar object specifies solution-dependent state variables.

    .. note:: 
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].depvar
            import odbMaterial
            session.odbs[name].materials[name].depvar

        The corresponding analysis keywords are:

        - DEPVAR
    """

    @abaqus_method_doc
    def __init__(self, deleteVar: int = 0, n: int = 0):
        """This method creates a Depvar object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].materials[name].Depvar
                session.odbs[name].materials[name].Depvar

        Parameters
        ----------
        deleteVar
            An Int specifying the state variable number controlling the element deletion flag. The
            default value is 0.This argument applies only to Abaqus/Explicit analyses.
        n
            An Int specifying the number of solution-dependent state variables required at each
            integration point. The default value is 0.

        Returns
        -------
        Depvar
            A :py:class:`~abaqus.Material.Others.User.Depvar.Depvar` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the Depvar object.

        Raises
        ------
        RangeError
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .Interaction import Interaction
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import PLANE, SymbolicConstant, TABULAR


@abaqus_class_doc
class AcousticImpedance(Interaction):
    """The AcousticImpedance object defines surface impedance information or nonreflecting
    boundaries for acoustic and coupled acoustic-structural analyses.
    The AcousticImpedance object is derived from the Interaction object.

    .. note:: 
        This object can be accessed by::

            import interaction
            mdb.models[name].interactions[name]

        The corresponding analysis keywords are:

        - SIMPEDANCE
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the step in which the AcousticImpedance object is
    #: created.
    createStepName: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the acoustic boundary surface.
    surface: Region

    #: A SymbolicConstant specifying the type of acoustic impedance to be defined. Possible
    #: values are TABULAR and NONREFLECTING. The default value is TABULAR.
    definition: SymbolicConstant = TABULAR

    #: A String specifying the AcousticImpedanceProp object associated with this interaction.
    interactionProperty: str = ""

    #: A SymbolicConstant specifying the type of nonreflecting geometry to be defined. Possible
    #: values are PLANE, IMPROVED, CIRCULAR, SPHERICAL, ELLIPTICAL, and PROLATE. The default
    #: value is PLANE.This argument is valid only when **definition** = NONREFLECTING.
    nonreflectingType: SymbolicConstant = PLANE

    #: A Float specifying the radius of the circle or sphere defining the boundary surface. The
    #: default value is 1.0.This argument is valid only when **definition** = NONREFLECTING, and
    #: **nonreflectingType** = CIRCULAR or SPHERICAL.
    radius: float = 1

    #: A Float specifying the semimajor axis length of the ellipse or prolate spheroid defining
    #: the boundary surface. The default value is 1.0.This argument is valid only when
    #: **definition** = NONREFLECTING, and **nonreflectingType** = ELLIPTICAL or PROLATE.
    semimajorAxis: float = 1

    #: A Float specifying the eccentricity of the ellipse or prolate spheroid defining the
    #: boundary surface. The default value is 0.0.This argument is valid only when
    #: **definition** = NONREFLECTING, and **nonreflectingType** = ELLIPTICAL or PROLATE.
    eccentricity: float = 0

    #: A sequence of three Floats specifying the X, Y, and Z coordinates of the center of the
    #: ellipse or prolate spheroid defining the boundary surface. The default value is (0, 0,
    #: 0).This argument is valid only when **definition** = NONREFLECTING, and
    #: **nonreflectingType** = ELLIPTICAL or PROLATE.
    centerCoordinates: tuple = ()

    #: A sequence of three Floats specifying the X, Y, and Z components of the direction cosine
    #: of the major axis of the ellipse or prolate spheroid defining the boundary surface. The
    #: default value is (0, 0, 1).This argument is valid only when **definition** = NONREFLECTING,
    #: and **nonreflectingType** = ELLIPTICAL or PROLATE.
    directionCosine: tuple = ()

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        surface: Region,
        definition: SymbolicConstant = TABULAR,
        interactionProperty: str = "",
        nonreflectingType: SymbolicConstant = PLANE,
        radius: float = 1,
        semimajorAxis: float = 1,
        eccentricity: float = 0,
        centerCoordinates: tuple = (),
        directionCosine: tuple = (),
    ):
        """This method creates an AcousticImpedance object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].AcousticImpedance

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the AcousticImpedance object is
            created.
        surface
            A :py:class:`~abaqus.Region.Region.Region` object specifying the acoustic boundary surface.
        definition
            A SymbolicConstant specifying the type of acoustic impedance to be defined. Possible
            values are TABULAR and NONREFLECTING. The default value is TABULAR.
        interactionProperty
            A String specifying the AcousticImpedanceProp object associated with this interaction.
        nonreflectingType
            A SymbolicConstant specifying the type of nonreflecting geometry to be defined. Possible
            values are PLANE, IMPROVED, CIRCULAR, SPHERICAL, ELLIPTICAL, and PROLATE. The default
            value is PLANE.This argument is valid only when **definition** = NONREFLECTING.
        radius
            A Float specifying the radius of the circle or sphere defining the boundary surface. The
            default value is 1.0.This argument is valid only when **definition** = NONREFLECTING, and
            **nonreflectingType** = CIRCULAR or SPHERICAL.
        semimajorAxis
            A Float specifying the semimajor axis length of the ellipse or prolate spheroid defining
            the boundary surface. The default value is 1.0.This argument is valid only when
            **definition** = NONREFLECTING, and **nonreflectingType** = ELLIPTICAL or PROLATE.
        eccentricity
            A Float specifying the eccentricity of the ellipse or prolate spheroid defining the
            boundary surface. The default value is 0.0.This argument is valid only when
            **definition** = NONREFLECTING, and **nonreflectingType** = ELLIPTICAL or PROLATE.
        centerCoordinates
            A sequence of three Floats specifying the X, Y, and Z coordinates of the center of the
            ellipse or prolate spheroid defining the boundary surface. The default value is (0, 0,
            0).This argument is valid only when **definition** = NONREFLECTING, and
            **nonreflectingType** = ELLIPTICAL or PROLATE.
        directionCosine
            A sequence of three Floats specifying the X, Y, and Z components of the direction cosine
            of the major axis of the ellipse or prolate spheroid defining the boundary surface. The
            default value is (0, 0, 1).This argument is valid only when **definition** = NONREFLECTING,
            and **nonreflectingType** = ELLIPTICAL or PROLATE.

        Returns
        -------
        AcousticImpedance
            An :py:class:`~abaqus.Interaction.AcousticImpedance.AcousticImpedance` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        definition: SymbolicConstant = TABULAR,
        interactionProperty: str = "",
        nonreflectingType: SymbolicConstant = PLANE,
        radius: float = 1,
        semimajorAxis: float = 1,
        eccentricity: float = 0,
        centerCoordinates: tuple = (),
        directionCosine: tuple = (),
    ):
        """This method modifies the data for an existing AcousticImpedance object in the step where
        it is created.

        Parameters
        ----------
        definition
            A SymbolicConstant specifying the type of acoustic impedance to be defined. Possible
            values are TABULAR and NONREFLECTING. The default value is TABULAR.
        interactionProperty
            A String specifying the AcousticImpedanceProp object associated with this interaction.
        nonreflectingType
            A SymbolicConstant specifying the type of nonreflecting geometry to be defined. Possible
            values are PLANE, IMPROVED, CIRCULAR, SPHERICAL, ELLIPTICAL, and PROLATE. The default
            value is PLANE.This argument is valid only when **definition** = NONREFLECTING.
        radius
            A Float specifying the radius of the circle or sphere defining the boundary surface. The
            default value is 1.0.This argument is valid only when **definition** = NONREFLECTING, and
            **nonreflectingType** = CIRCULAR or SPHERICAL.
        semimajorAxis
            A Float specifying the semimajor axis length of the ellipse or prolate spheroid defining
            the boundary surface. The default value is 1.0.This argument is valid only when
            **definition** = NONREFLECTING, and **nonreflectingType** = ELLIPTICAL or PROLATE.
        eccentricity
            A Float specifying the eccentricity of the ellipse or prolate spheroid defining the
            boundary surface. The default value is 0.0.This argument is valid only when
            **definition** = NONREFLECTING, and **nonreflectingType** = ELLIPTICAL or PROLATE.
        centerCoordinates
            A sequence of three Floats specifying the X, Y, and Z coordinates of the center of the
            ellipse or prolate spheroid defining the boundary surface. The default value is (0, 0,
            0).This argument is valid only when **definition** = NONREFLECTING, and
            **nonreflectingType** = ELLIPTICAL or PROLATE.
        directionCosine
            A sequence of three Floats specifying the X, Y, and Z components of the direction cosine
            of the major axis of the ellipse or prolate spheroid defining the boundary surface. The
            default value is (0, 0, 1).This argument is valid only when **definition** = NONREFLECTING,
            and **nonreflectingType** = ELLIPTICAL or PROLATE.
        """
        ...

    @abaqus_method_doc
    def setValuesInStep(self, stepName: str, interactionProperty: str = ""):
        """This method modifies the propagating data for an existing AcousticImpedance object in
        the specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the interaction is modified.
        interactionProperty
            A String specifying the AcousticImpedanceProp object associated with this interaction.
        """
        ...



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="abqpy",
    author="WANG Hailin",
    author_email="hailin.wang@connect.polyu.hk",
    description="Type hints for Abaqus/Python scripting",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://abqpy.com",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: Implementation :: PyPy",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    project_urls={
        'GitHub': 'https://github.com/haiiliin/abqpy',
        'Bug Tracker': 'https://github.com/haiiliin/abqpy/issues',
        'Documentation': 'https://docs.abqpy.com',
        'Anaconda': 'https://anaconda.org/haiiliin/abqpy',
        'Read the Docs': 'https://readthedocs.org/projects/abqpy',
    },
    use_scm_version={
        "root": ".",
        "relative_to": __file__,
        "local_scheme": "node-and-date",
        "write_to": "src/abqpy/_version.py",
        "fallback_version": "2023.0.0-dev",
    },
    setup_requires=['setuptools_scm'],
    python_requires='>=3.7',
    package_dir={'': 'src'},
    install_requires=['typing-extensions', 'auto-all', 'Jinja2', 'toml'],
    packages=setuptools.find_packages('src'),
    py_modules=['ababltin', 'abaqusConstants', 'animation', 'annotationToolset', 'assembly', 'caeModules',
                'caePrefsAccess', 'calibration', 'connectorBehavior', 'customKernel', 'deleteObjectCallback',
                'displayGroupMdbToolset', 'displayGroupOdbToolset', 'driverUtils', 'field', 'fields', 'inpParser',
                'interaction', 'material', 'mesh', 'meshEdit', 'methodCallback', 'monitorManager', 'odbAccess',
                'odbConnectorBehavior', 'odbMaterial', 'odbSection', 'part', 'redentABQ', 'section',
                'symbolicConstants', 'textRepr', 'upgradeScript', 'visualization', 'regionToolset', 'step', 'load',
                'optimization', 'job', 'sketch', 'xyPlot'],
    entry_points={
        'console_scripts': [
            'abqpy = abqpy.__main__:cli',
        ]
    },
    package_data={'abqpy': ['templates/*.toml', 'templates/*.tmpl']},
)



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .Interaction import Interaction
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import LAGRANGIAN, SymbolicConstant, UNIFORM


@abaqus_class_doc
class ConcentratedRadiationToAmbient(Interaction):
    """The ConcentratedRadiationToAmbient object defines radiant heat transfer between a point
    and its nonreflecting environment.
    The ConcentratedRadiationToAmbient object is derived from the Interaction object.

    .. note:: 
        This object can be accessed by::

            import interaction
            mdb.models[name].interactions[name]
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the step in which the ConcentratedRadiationToAmbient
    #: object is created.
    createStepName: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the concentrated radiation interaction is
    #: applied. The interaction is applied to each node in the region.
    region: Region

    #: A Float specifying the reference ambient temperature, θ0θ0.
    ambientTemperature: float

    #: A String specifying the name of the Amplitude object that gives the variation of the
    #: ambient temperature with time.Note:Use None in an Abaqus/Standard analysis to specify
    #: that the reference ambient temperature is applied immediately at the beginning of the
    #: step or linearly over the step. Use None in an Abaqus/Explicit analysis to specify that
    #: the reference ambient temperature is applied throughout the step.
    ambientTemperatureAmp: str

    #: A Float specifying the emissivity, ϵϵ.
    emissivity: float

    #: A Float specifying the area associated with the node where the concentrated radiation
    #: interaction is applied. The default value is 1.0.
    nodalArea: float = 1

    #: A SymbolicConstant specifying how the concentrated radiation is applied to the boundary
    #: of an adaptive mesh domain. Possible values are LAGRANGIAN, SLIDING, and EULERIAN. The
    #: default value is LAGRANGIAN.Note:*explicitRegionType* applies only during an
    #: Abaqus/Explicit analysis.
    explicitRegionType: SymbolicConstant = LAGRANGIAN

    #: A String specifying the name of the AnalyticalField object associated with this
    #: interaction. The **field** argument applies only when **distributionType** = ANALYTICAL_FIELD.
    #: The default value is an empty string.
    field: str = ""

    #: A SymbolicConstant specifying how the radiation is defined. Possible values are UNIFORM
    #: and ANALYTICAL_FIELD. The default value is UNIFORM.
    distributionType: SymbolicConstant = UNIFORM

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        region: Region,
        ambientTemperature: float,
        ambientTemperatureAmp: str,
        emissivity: float,
        nodalArea: float = 1,
        explicitRegionType: SymbolicConstant = LAGRANGIAN,
        field: str = "",
        distributionType: SymbolicConstant = UNIFORM,
    ):
        """This method creates a ConcentratedRadiationToAmbient object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].ConcentratedRadiationToAmbient

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the ConcentratedRadiationToAmbient
            object is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the concentrated radiation interaction is
            applied. The interaction is applied to each node in the region.
        ambientTemperature
            A Float specifying the reference ambient temperature, θ0θ0.
        ambientTemperatureAmp
            A String specifying the name of the Amplitude object that gives the variation of the
            ambient temperature with time.Note:Use None in an Abaqus/Standard analysis to specify
            that the reference ambient temperature is applied immediately at the beginning of the
            step or linearly over the step. Use None in an Abaqus/Explicit analysis to specify that
            the reference ambient temperature is applied throughout the step.
        emissivity
            A Float specifying the emissivity, ϵϵ.
        nodalArea
            A Float specifying the area associated with the node where the concentrated radiation
            interaction is applied. The default value is 1.0.
        explicitRegionType
            A SymbolicConstant specifying how the concentrated radiation is applied to the boundary
            of an adaptive mesh domain. Possible values are LAGRANGIAN, SLIDING, and EULERIAN. The
            default value is LAGRANGIAN.Note:*explicitRegionType* applies only during an
            Abaqus/Explicit analysis.
        field
            A String specifying the name of the AnalyticalField object associated with this
            interaction. The **field** argument applies only when **distributionType** = ANALYTICAL_FIELD.
            The default value is an empty string.
        distributionType
            A SymbolicConstant specifying how the radiation is defined. Possible values are UNIFORM
            and ANALYTICAL_FIELD. The default value is UNIFORM.

        Returns
        -------
        ConcentratedRadiationToAmbient
            A :py:class:`~abaqus.Interaction.ConcentratedRadiationToAmbient.ConcentratedRadiationToAmbient` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        nodalArea: float = 1,
        explicitRegionType: SymbolicConstant = LAGRANGIAN,
        field: str = "",
        distributionType: SymbolicConstant = UNIFORM,
    ):
        """This method modifies the data for an existing ConcentratedRadiationToAmbient object in
        the step where it is created.

        Parameters
        ----------
        nodalArea
            A Float specifying the area associated with the node where the concentrated radiation
            interaction is applied. The default value is 1.0.
        explicitRegionType
            A SymbolicConstant specifying how the concentrated radiation is applied to the boundary
            of an adaptive mesh domain. Possible values are LAGRANGIAN, SLIDING, and EULERIAN. The
            default value is LAGRANGIAN.Note:*explicitRegionType* applies only during an
            Abaqus/Explicit analysis.
        field
            A String specifying the name of the AnalyticalField object associated with this
            interaction. The **field** argument applies only when **distributionType** = ANALYTICAL_FIELD.
            The default value is an empty string.
        distributionType
            A SymbolicConstant specifying how the radiation is defined. Possible values are UNIFORM
            and ANALYTICAL_FIELD. The default value is UNIFORM.
        """
        ...

    @abaqus_method_doc
    def setValuesInStep(
        self,
        stepName: str,
        nodalArea: float = 1,
        field: str = "",
        distributionType: SymbolicConstant = UNIFORM,
    ):
        """This method modifies the propagating data of an existing ConcentratedRadiationToAmbient
        object in the specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the interaction is modified.
        nodalArea
            A Float specifying the area associated with the node where the concentrated radiation
            interaction is applied. The default value is 1.0.
        field
            A String specifying the name of the AnalyticalField object associated with this
            interaction. The **field** argument applies only when **distributionType** = ANALYTICAL_FIELD.
            The default value is an empty string.
        distributionType
            A SymbolicConstant specifying how the radiation is defined. Possible values are UNIFORM
            and ANALYTICAL_FIELD. The default value is UNIFORM.
        """
        ...



from typing import Optional

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .Leaf import Leaf
from ..Part.Part import Part
from ..UtilityAndView.abaqusConstants import DEFAULT_MODEL, SymbolicConstant


@abaqus_class_doc
class LeafFromPartElementLabels(Leaf):
    """The LeafFromPartElementLabels object can be used whenever a Leaf object is expected as
    an argument. Leaf objects are used to specify the items in a display group. Leaf objects
    are constructed as temporary objects, which are then used as arguments to DisplayGroup
    commands.
    The LeafFromPartElementLabels object is derived from the Leaf object.

    .. note:: 
        This object can be accessed by::

            import displayGroupMdbToolset
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
    #: DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.
    leafType: Optional[SymbolicConstant] = None

    @abaqus_method_doc
    def __init__(self, part: Part, elementLabels: tuple):
        """This method creates a Leaf object from a sequence of Strings specifying element labels.
        Leaf objects specify the items in a display group.

        .. note:: 
            This function can be accessed by::

                LeafFromPartElementLabels

        Parameters
        ----------
        part
            A :py:class:`~abaqus.Part.Part.Part` object.
        elementLabels
            A sequence of Strings specifying element labels.

        Returns
        -------
        LeafFromPartElementLabels
            A :py:class:`~abaqus.DisplayGroup.LeafFromPartElementLabels.LeafFromPartElementLabels` object.
        """
        super().__init__(DEFAULT_MODEL)



from typing import Union

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from ..UtilityAndView.abaqusConstants import (DPI_150, INCHES, MEDIUM, PS_IF_AVAILABLE,
                                              SIZE_ON_SCREEN, SymbolicConstant, VECTOR)
from .._OptionsBase import _OptionsBase


@abaqus_class_doc
class EpsOptions(_OptionsBase):
    """The EpsOptions object stores the settings that Abaqus uses when printing using
    Encapsulated PostScript format. The EpsOptions object has no constructor. Abaqus creates
    the **epsOptions** member when a session is started.

    .. note:: 
        This object can be accessed by::

            session.epsOptions
    """
    #: The SymbolicConstant SIZE_ON_SCREEN or a pair of Floats specifying the width and height
    #: of the image in the units specified by **units**. Possible numeric values are **imageSize**
    #: ≥ (*minWidth*, **minHeight**). The default value is SIZE_ON_SCREEN.Note:The minimum value
    #: of width and height (*minWidth* and **minHeight**) is 10 mm (approximately 0.4 inches).
    imageSize: Union[SymbolicConstant, float] = SIZE_ON_SCREEN

    #: A SymbolicConstant specifying the units of the **imageSize** argument. This argument is
    #: ignored if **imageSize** is SIZE_ON_SCREEN. Possible values are INCHES and MM. The default
    #: value is INCHES.
    units: SymbolicConstant = INCHES

    #: A SymbolicConstant specifying the resolution of the image in dots per inch (dpi). The
    #: **resolution** can be DPI_1200 only if **imageFormat** = VECTOR. Possible values are DPI_75,
    #: DPI_150, DPI_300, DPI_450, DPI_600, and DPI_1200. The default value is DPI_150.
    resolution: SymbolicConstant = DPI_150

    #: A SymbolicConstant specifying the PostScript font substitution rules to be applied.
    #: Possible values are PS_ALWAYS, PS_IF_AVAILABLE, and AS_DISPLAYED. The default value is
    #: PS_IF_AVAILABLE.
    fontType: SymbolicConstant = PS_IF_AVAILABLE

    #: A SymbolicConstant specifying how the viewport display will be represented. Possible
    #: values are VECTOR and RASTER. The default value is VECTOR.
    imageFormat: SymbolicConstant = VECTOR

    #: A SymbolicConstant specifying how fine the shading of curved surfaces will be for vector
    #: images. Possible values are EXTRA COARSE, COARSE, MEDIUM, FINE, and EXTRA FINE. The default
    #: value is MEDIUM.
    shadingQuality: SymbolicConstant = MEDIUM

    @abaqus_method_doc
    def setValues(
        self,
        *,
        imageSize: Union[SymbolicConstant, float] = SIZE_ON_SCREEN,
        units: SymbolicConstant = INCHES,
        resolution: SymbolicConstant = DPI_150,
        fontType: SymbolicConstant = PS_IF_AVAILABLE,
        imageFormat: SymbolicConstant = VECTOR,
        shadingQuality: SymbolicConstant = MEDIUM,
    ):
        """This method modifies the EpsOptions object.

        Parameters
        ----------
        imageSize
            The SymbolicConstant SIZE_ON_SCREEN or a pair of Floats specifying the width and height
            of the image in the units specified by **units**. Possible numeric values are **imageSize**
            ≥ (*minWidth*, **minHeight**). The default value is SIZE_ON_SCREEN.Note:The minimum value
            of width and height (*minWidth* and **minHeight**) is 10 mm (approximately 0.4 inches).
        units
            A SymbolicConstant specifying the units of the **imageSize** argument. This argument is
            ignored if **imageSize** is SIZE_ON_SCREEN. Possible values are INCHES and MM. The default
            value is INCHES.
        resolution
            A SymbolicConstant specifying the resolution of the image in dots per inch (dpi). The
            **resolution** can be DPI_1200 only if **imageFormat** = VECTOR. Possible values are DPI_75,
            DPI_150, DPI_300, DPI_450, DPI_600, and DPI_1200. The default value is DPI_150.
        fontType
            A SymbolicConstant specifying the PostScript font substitution rules to be applied.
            Possible values are PS_ALWAYS, PS_IF_AVAILABLE, and AS_DISPLAYED. The default value is
            PS_IF_AVAILABLE.
        imageFormat
            A SymbolicConstant specifying how the viewport display will be represented. Possible
            values are VECTOR and RASTER. The default value is VECTOR.
        shadingQuality
            A SymbolicConstant specifying how fine the shading of curved surfaces will be for vector
            images. Possible values are EXTRA COARSE, COARSE, MEDIUM, FINE, and EXTRA FINE. The
            default value is MEDIUM.

        Raises
        ------
        RangeError: imageSize must be SIZE_ON_SCREEN or a sequence of 2 Floats >= (*minWidth*, **minHeight**)
            If either element of **imageSize** is out of range.
        """
        super().setValues(
            imageSize=imageSize,
            units=units,
            resolution=resolution,
            fontType=fontType,
            imageFormat=imageFormat,
            shadingQuality=shadingQuality
        )
